// BWDeletableTableView.m -- implementation to an NSTableView subclass
//                           that tells its datasource to remove a row 
//                           when the user presses the delete key

#import "BWDeletableTableView.h"


@implementation BWDeletableTableView

// since we're wanting to catch key presses, this is the place to
// do it

- (void) keyDown: (NSEvent *) event
{
    NSString *characters;

    characters = [event charactersIgnoringModifiers];

    unichar character;
    character = [characters characterAtIndex: 0];

    // NSDeleteFunctionKey is only being provided to me on my tiBook
    // if I do fn-Delete.  Regular delete sends character 0x7F, ascii
    // DEL

    if (character == NSDeleteFunctionKey 
	|| character == 0x7F
	|| character == NSDeleteCharFunctionKey) {

	// if the datasource responds to the nuke selector, sendit

	if ([[self dataSource] 
		respondsToSelector: @selector(tableView:shouldDeleteRow:)]) {
	    
	    // assumes just one row selected.  Which is adequate
	    // for the Stackinator
	    int selectedRow;
	    selectedRow = [self selectedRow];

	    if (selectedRow >= 0) {
		[[self dataSource] tableView: self  
				   shouldDeleteRow: selectedRow];
	    }
	}

    } else {
	[super keyDown: event];
    }

} // keyDown


@end // BWDeletableTableView

